Example of cutoff threshold from plus model for use in the consturctor function new_plus
cutoff_example.RdExample of cutoff threshold from plus model for use in the consturctor function new_plus
Usage
data(cutoff_example)Examples
data(cutoff_example)