Example of prediction from plus model for use in the consturctor function new_plus
predicted_coefficients_example.RdExample of prediction from plus model for use in the consturctor function new_plus
Usage
data(predicted_coefficients_example)Format
An object of class "dgCMatrix"; it contains the coefficients of the model for each variable in the rows
Examples
data(predicted_coefficients_example)