Example of prediction from plus model for use in the consturctor function new_plus
predicted_y_example.RdExample of prediction from plus model for use in the consturctor function new_plus
Usage
data(predicted_y_example)Examples
data(predicted_y_example)